
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#include <math.h>
#include <iostream.h>

#include "Primitive.H"

// class Primitive member functions

void 
Primitive::emitPovraySource
  (const Matrix4)
{
   povraySource << "emitPovraySource - virtual function not defined for primitive\n";
}

void 
Primitive::emitSiscadSource
  (const Matrix4)
{
   siscadSource << "emitSiscadSource - virtual function not defined for primitive\n";
}


// class Cylinder member functions

Cylinder::Cylinder
  (const Vector3 p1, const Vector3 p2, const double rad )
{
   end1 = p1;
   end2 = p2;
   radius = rad;
}

void 
Cylinder::emitPovraySource
  (const Matrix4 transformation)
{
   povraySource << "cylinder {\n";
   povraySource << "   ";
   end1.emitPovraySource(transformation);
   povraySource << ", ";
   end2.emitPovraySource(transformation);
   povraySource << ", ";
   povraySource << radius;
   povraySource << "\n";
   povraySource << "   texture { MyTexture1 }\n";
   povraySource << "}\n";
}

void 
Cylinder::emitSiscadSource
  (const Matrix4 transformation)
{
   Matrix4 trans = transformation;
   Vector3 p1 = end1;
   Vector3 p2 = end2;
   Vector3 p1t = trans * p1;
   Vector3 p2t = trans * p2;
   if ((p1t[VX] != p2t[VX])||(p1t[VZ] != p2t[VZ]))
      {
         // centreline
         // siscadSource << "CREATE LINE PP ";
         // siscadSource << p1t[VX] << ", " << p1t[VZ] << "; ";
         // siscadSource << p2t[VX] << ", " << p2t[VZ] << ";!";
         // siscadSource << "\n";

	 // outline
	 double rotation = atan2(p2t[VZ] - p1t[VZ], p2t[VX] - p1t[VX]);
	 Vector2 p1_ (p1t[VX], p1t[VZ]);
	 Vector2 p2_ (p2t[VX], p2t[VZ]);
	 Matrix3 trans2d = rotation2D(p1_, -rotation*180/PI);
	 Vector2 p2_t = trans2d * p2_;
	 Vector2 offset (0.0, radius);
	 Vector2 pa1 = p1_ + offset;
	 Vector2 pa2 = p2_t + offset;
	 Vector2 pb1 = p1_ - offset;
	 Vector2 pb2 = p2_t - offset;
	 Matrix3 trans2d_ = rotation2D(p1_, rotation*180/PI);
	 Vector2 pa1t = trans2d_ * pa1;
	 Vector2 pa2t = trans2d_ * pa2;
	 Vector2 pb1t = trans2d_ * pb1;
	 Vector2 pb2t = trans2d_ * pb2;
         siscadSource << "CREATE LINE PP ";
         siscadSource << pa1t[VX] << ", " << pa1t[VY] << "; ";
         siscadSource << pa2t[VX] << ", " << pa2t[VY] << ";!";
         siscadSource << "\n";
         siscadSource << "CREATE LINE PP ";
         siscadSource << pb1t[VX] << ", " << pb1t[VY] << "; ";
         siscadSource << pb2t[VX] << ", " << pb2t[VY] << ";!";
         siscadSource << "\n";
         siscadSource << "CREATE LINE PP ";
         siscadSource << pa1t[VX] << ", " << pa1t[VY] << "; ";
         siscadSource << pb1t[VX] << ", " << pb1t[VY] << ";!";
         siscadSource << "\n";
         siscadSource << "CREATE LINE PP ";
         siscadSource << pa2t[VX] << ", " << pa2t[VY] << "; ";
         siscadSource << pb2t[VX] << ", " << pb2t[VY] << ";!";
         siscadSource << "\n";

      }
}


// class Sphere member functions

Sphere::Sphere
  (const Vector3 p, const double rad )
{
   centre = p;
   radius = rad;
}

void 
Sphere::emitPovraySource
  (const Matrix4 transformation)
{
   povraySource << "sphere {\n";
   povraySource << "   ";
   centre.emitPovraySource(transformation);
   povraySource << ", ";
   povraySource << radius;
   povraySource << "\n";
   povraySource << "   texture { MyTexture1 }\n";
   povraySource << "}\n";
}

void 
Sphere::emitSiscadSource
  (const Matrix4 transformation)
{
   Vector3 p = centre;
   Vector3 pt = transformation * p;
   siscadSource << "CREATE CIRCLE CTRD ";
   // siscadSource << centre.x() << ", " << centre.z() << "; ";
   siscadSource << pt[VX] << ", " << pt[VZ] << "; ";
   siscadSource << 2*radius << ";!";
   siscadSource << "\n";
}


// class Box member functions

Box::Box
  (const Vector3 p1, const Vector3 p2)
{
   corner1 = p1;
   corner2 = p2;
}

void 
Box::emitPovraySource
  (const Matrix4 transformation)
{
   povraySource << "box {\n";
   povraySource << "   ";
   corner1.emitPovraySource(transformation);
   povraySource << ", ";
   corner2.emitPovraySource(transformation);
   povraySource << "\n";
   povraySource << "   texture { MyTexture1 }\n";
   povraySource << "}\n";
}

void 
Box::emitSiscadSource
  (const Matrix4)
{
}


// class Cone member functions

Cone::Cone
  (const Vector3 p1, const double rad1,
   const Vector3 p2, const double rad2)
{
   end1 = p1;
   end2 = p2;
   radius1 = rad1;
   radius2 = rad2;
}

void 
Cone::emitPovraySource
  (const Matrix4 transformation)
{
   povraySource << "cone {\n";
   povraySource << "   ";
   end1.emitPovraySource(transformation);
   povraySource << ", ";
   povraySource << radius1;
   povraySource << ", ";
   end2.emitPovraySource(transformation);
   povraySource << ", ";
   povraySource << radius2;
   povraySource << "\n";
   povraySource << "   texture { MyTexture1 }\n";
   povraySource << "}\n";
}

void 
Cone::emitSiscadSource
  (const Matrix4)
{
/*
   if ((end1.x() != end2.x())||(end1.z() != end2.z()))
      {
         siscadSource << "CREATE LINE PP ";
         siscadSource << end1.x() << ", " << end1.z() << "; ";
         siscadSource << end2.x() << ", " << end2.z() << ";!";
         siscadSource << "\n";
      }
*/
}


// experimental

// class Union member functions

Union::Union
  (Primitive& prim1, Primitive& prim2)
{
   primitive1 = &prim1;
   primitive2 = &prim2;
}

void 
Union::emitPovraySource
  (const Matrix4 transformation)
{
   povraySource << "union {\n";
   povraySource << "   ";
   primitive1->emitPovraySource(transformation);
   povraySource << ", ";
   primitive2->emitPovraySource(transformation);
   povraySource << "\n";
   povraySource << "   texture { MyTexture1 }\n";
   povraySource << "}\n";
}

void 
Union::emitSiscadSource
  (const Matrix4)
{
}
