
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#ifndef PrimitiveClasses
#define PrimitiveClasses

#include <math.h>
#include <iostream.h>

#include "Files.H"
#include "Vector2.H"
#include "Vector3.H"
#include "Matrix4.H"

class Primitive
{
   public:
      Primitive() {};
      virtual void emitPovraySource
        (const Matrix4);
      virtual void emitSiscadSource
        (const Matrix4);
};


// Cylinder primitive

class Cylinder: public Primitive
{
   public:
      Cylinder() {};
      Cylinder
        (const Vector3 p1, const Vector3 p2, const double rad );
      void emitPovraySource
        (const Matrix4 transformation);
      void emitSiscadSource
        (const Matrix4 transformation);
   private:
      Vector3 end1, end2;
      double radius;
};


// Sphere primitive

class Sphere: public Primitive
{
   public:
      Sphere() {};
      Sphere
        (const Vector3 p, const double rad );
      void emitPovraySource
        (const Matrix4 transformation);
      void emitSiscadSource
        (const Matrix4 transformation);
   private:
      Vector3 centre;
      double radius;
};


// Box primitive

class Box: public Primitive
{
   public:
      Box() {};
      Box
        (const Vector3 p1, const Vector3 p2);
      void emitPovraySource
        (const Matrix4 transformation);
      void emitSiscadSource
        (const Matrix4);
   private:
      Vector3 corner1, corner2;
};


// Cone primitive

class Cone: public Primitive
{
   public:
      Cone() {};
      Cone
        (const Vector3 p1, const double rad1,
         const Vector3 p2, const double rad2);
      void emitPovraySource
        (const Matrix4 transformation);
      void emitSiscadSource
        (const Matrix4);
   private:
      Vector3 end1, end2;
      double radius1, radius2;
};


// experimental

class Union: public Primitive
{
   public:
      Union() {};
      Union
        (Primitive& prim1, Primitive& prim2);
      void emitPovraySource
        (const Matrix4 transformation);
      void emitSiscadSource
        (const Matrix4);
   private:
      Primitive *primitive1, *primitive2;
};

#endif
