
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#include "HexapodFrame.H"
#include "HexapodBed.H"
#include "HexapodLeg.H"
#include "HexapodTopJoint.H"
#include "HexapodBottomJoint.H"
#include "HexapodPlatform.H"
#include "HexapodMechanism.H"

void
defineParameters(FrameParameters& frameParameters,
                 BedParameters& bedParameters,
	         MechanismParameters& mechanismParameters)
{
   frameParameters.bottomHeight = 0.0;
   frameParameters.centreHeight = 700.0;
   frameParameters.topHeight = 2300;
   frameParameters.bottomWidth = 1060.0;
   frameParameters.centreWidth = 1500.0;
   frameParameters.topWidth = 1060.0;
   frameParameters.tubeRadius = 27.5;
   frameParameters.sphereRadius = 27.5;

   bedParameters.width = 1200.0;
   bedParameters.height = 725.0;
   bedParameters.thickness = 100.0;
   bedParameters.supportTubeRadius = 15.0;
   
   LegParameters legParameters;
   legParameters.screwDiameter = 20.0;
   legParameters.screwLength = 869; //839.0;
   legParameters.screwTopLength = 150.0;
   legParameters.screwBottomLength = 32.0;
   legParameters.nutDiameter = 36.0;
   legParameters.nutLength = 80.0;
   legParameters.nutTubeOD = 47.0;
   legParameters.nutTubeID = 38.0;
   legParameters.nutTubeBottomLength = 150.0;
   legParameters.shroudTubeDiameter = 55.0;
   legParameters.shroudTubeLength = 1000.0; // not independent
   legParameters.totalBacklash = 0; // joint bearings + screw/nut -- critical!!
   legParameters.nutTubeLength = 
      legParameters.screwLength + legParameters.screwBottomLength;
   legParameters.legLength = 0.0;  // currently undefined

   TopJointParameters topJointParameters;
   topJointParameters.ballRadius = 25.0;

   BottomJointParameters bottomJointParameters;
   bottomJointParameters.ballRadius = 25.0;

   PlatformParameters platformParameters;
   platformParameters.radius = 150.0;
   platformParameters.thickness = 40.0;

   mechanismParameters.topCircleRadius = 540.0; //550.0;
   mechanismParameters.bottomCircleRadius = 125.0;
   mechanismParameters.legPairSectorAngle = 1.9; // radians
   mechanismParameters.supportHeight = 2300.0;
   mechanismParameters.platformHeight = 1000.0; // initial
   mechanismParameters.legParameters = legParameters;
   mechanismParameters.topJointParameters = topJointParameters;
   mechanismParameters.bottomJointParameters = bottomJointParameters;
   mechanismParameters.platformParameters = platformParameters;
}
