
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#include "Files.H"
#include "Matrix4.H"
#include "HexapodFrame.H"
#include "HexapodBed.H"
#include "HexapodLeg.H"
#include "HexapodTopJoint.H"
#include "HexapodBottomJoint.H"
#include "HexapodPlatform.H"
#include "HexapodMechanism.H"

void 
defineParameters(FrameParameters& frameParameters,
                 BedParameters& bedParameters,
                 MechanismParameters& mechanismParameters);

main()
{
   FrameParameters frameParameters;
   BedParameters bedParameters;
   MechanismParameters mechanismParameters;
   defineParameters(frameParameters, bedParameters, mechanismParameters);

   HexapodFrame hexapodFrame ("hexapod frame", frameParameters);
   HexapodBed hexapodBed ("hexapod bed", bedParameters);
   HexapodMechanism hexapodMechanism ("hexapod mechanism", mechanismParameters);

   int page = 0;   // format control

   for (int correction = 0; correction <5; correction++)
      for (int location = 0; location <1; location++)
         for (int axis = 0; axis <1; axis++)
	    {

	       if (page == 0)  // print title
	          {
   // <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
   coefficient << 
      "\n\n   CALIBRATION COEFFICIENTS FOR A SINGLE CORRECTION - %\n";
   // >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
		  }

   for (double z = 800; z < 900; z += 300)
      {
         coefficient << "\n   z = " << z << '\n';
   coefficient << "   CORRECTION = " << correction 
               << "   LOCATION = " << location
               << "   AXIS = " << axis << '\n';

         for (double y = -600; y <= 600; y += 50)
            {
	       int print = 1;

	       coefficient << "   ";

               for (double x = -600; x <= 600; x += 50)
                  {
                     hexapodMechanism.movePlatformTo(Vector3(0, 0, 0),
	                                             Vector3(x, y, z));
		     if (print == 1) 
		        {
			   hexapodMechanism.computeCalibrationCoefficients();
			   hexapodMechanism.reportCoefficient
			                       (correction, location, axis);
			   print = 0;
			}
		     else
			print = 1;
	          }
	       coefficient <<'\n';
            }

	 if (page == 1)
	    {
	       // new page required
	       coefficient <<'\f';
	       page = 0;
	    }
	 else
	    page = 1;
      }


	    }
}
