
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#include "Files.H"
#include "Matrix4.H"
#include "HexapodFrame.H"
#include "HexapodBed.H"
#include "HexapodLeg.H"
#include "HexapodTopJoint.H"
#include "HexapodBottomJoint.H"
#include "HexapodPlatform.H"
#include "HexapodMechanism.H"

void 
defineParameters(FrameParameters& frameParameters,
                 BedParameters& bedParameters,
                 MechanismParameters& mechanismParameters);

void 
printParameters(FrameParameters& frameParameters,
                BedParameters& bedParameters,
                MechanismParameters& mechanismParameters);

main()
{
   FrameParameters frameParameters;
   BedParameters bedParameters;
   MechanismParameters mechanismParameters;
   defineParameters(frameParameters, bedParameters, mechanismParameters);
   printParameters(frameParameters, bedParameters, mechanismParameters);

   HexapodFrame hexapodFrame ("hexapod frame", frameParameters);
   HexapodBed hexapodBed ("hexapod bed", bedParameters);
   HexapodMechanism hexapodMechanism ("hexapod mechanism", mechanismParameters);

   int page = 0;   // format control

   //for (double z = 700; z < 1400; z += 50)
   for (double z = 800; z < 1200; z += 100)
      {
         if (page == 0)  // print title
	    {

   // <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
   rangeChecks << "\n\n   LEG RANGE CHECK - L = TOO LONG, S = TOO SHORT\n";
   minAngleACB << "\n\n   MIN ANGLE ACB - LEG PAIR TRIANGLE BOTTOM - DEGREES\n";
   maxAngleACB << "\n\n   MAX ANGLE ACB - LEG PAIR TRIANGLE BOTTOM - DEGREES\n";
   minAngleBAC <<
      "\n\n   MIN ANGLE BAC AND ABC - LEG PAIR TRIANGLE TOP - DEGREES\n";
   maxAngleBAC <<
      "\n\n   MAX ANGLE BAC AND ABC - LEG PAIR TRIANGLE TOP - DEGREES\n";
   minAngleGCV <<
     "\n\n   MIN ANGLE GCV - LEG PAIR TRIANGLE PLANE TO HORIZONTAL - DEGREES\n";
   maxAngleGCV <<
     "\n\n   MAX ANGLE GCV - LEG PAIR TRIANGLE PLANE TO HORIZONTAL - DEGREES\n";
   minAngleACF <<
     "\n\n   MIN ANGLE ACF AND BCF - LEG TO BOTTOM JOINT LONG AXIS - DEGREES\n";
   maxAngleACF <<
     "\n\n   MAX ANGLE ACF AND BCF - LEG TO BOTTOM JOINT LONG AXIS - DEGREES\n";
   minAngleGCH << "\n\n" <<
     "   MIN ANGLE GCH - LEG PAIR TRIANGLE PLANE TO PLATFORM PLANE - DEGREES\n";
   maxAngleGCH << "\n\n" << 
     "   MAX ANGLE GCH - LEG PAIR TRIANGLE PLANE TO PLATFORM PLANE - DEGREES\n";
   minLegForce << "\n\n   MIN ABSOLUTE LEG FORCE UNDER TEST LOAD - NEWTONS\n";
   maxLegForce << "\n\n   MAX ABSOLUTE LEG FORCE UNDER TEST LOAD - NEWTONS\n";
   resolutionErrors 
      << "\n\n   RESOLUTION ERRORS - CEILING(ERROR/RESOLUTION)\n";
   displacement << "\n\n   CUTTER DISPLACEMENT UNDER TEST LOAD - MICRONS\n";
   // >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

	    }

         rangeChecks << "\n   z = " << z << '\n';
         minAngleACB << "\n   z = " << z << '\n';
         maxAngleACB << "\n   z = " << z << '\n';
         minAngleBAC << "\n   z = " << z << '\n';
         maxAngleBAC << "\n   z = " << z << '\n';
         minAngleGCV << "\n   z = " << z << '\n';
         maxAngleGCV << "\n   z = " << z << '\n';
         minAngleACF << "\n   z = " << z << '\n';
         maxAngleACF << "\n   z = " << z << '\n';
         minAngleGCH << "\n   z = " << z << '\n';
         maxAngleGCH << "\n   z = " << z << '\n';
         minLegForce << "\n   z = " << z << '\n';
         maxLegForce << "\n   z = " << z << '\n';
         displacement << "\n   z = " << z << '\n';
         resolutionErrors << "\n   z = " << z << '\n';

         for (double y = -600; y <= 600; y += 50)
            {
	       int print = 1;  // print control

	       rangeChecks << "   ";
	       minAngleACB << "   ";
	       maxAngleACB << "   ";
	       minAngleBAC << "   ";
	       maxAngleBAC << "   ";
	       minAngleGCV << "   ";
	       maxAngleGCV << "   ";
	       minAngleACF << "   ";
	       maxAngleACF << "   ";
	       minAngleGCH << "   ";
	       maxAngleGCH << "   ";
	       minLegForce << "   ";
	       maxLegForce << "   ";
	       displacement << "   ";
	       resolutionErrors << "   ";

               for (double x = -600; x <= 600; x += 50)
                  {
                   //hexapodMechanism.movePlatformTo(Vector3(0, 0, 0),
                   //hexapodMechanism.movePlatformTo(Vector3(PI/6, 0, 0),
                   //hexapodMechanism.movePlatformTo(Vector3(0, PI/6, 0),
                   hexapodMechanism.movePlatformTo(Vector3(PI/9, PI/9, 0),
                   //hexapodMechanism.movePlatformTo(Vector3(PI/6, 0, PI/6),
                   //hexapodMechanism.movePlatformTo(Vector3(PI/6, PI/6, PI/6),
                   //hexapodMechanism.movePlatformTo(Vector3(0, 0, PI/4),
	                                             Vector3(x, y, z));
		     hexapodMechanism.applyCutterForce(Vector3(50, 50, 0),
		                                       Vector3(x, y, z - 150));
	             hexapodMechanism.reportRangeStatus();
		     if (print == 1) 
		         // print every second value for square report format
		        {
	                   hexapodMechanism.reportAngles();
	                   hexapodMechanism.reportForces();
	                   hexapodMechanism.reportDisplacement();
	                   hexapodMechanism.reportResolutionError();
			   print = 0;
			}
		     else
			print = 1;
	          }
              
	       rangeChecks <<'\n';
	       minAngleACB <<'\n';
	       maxAngleACB <<'\n';
	       minAngleBAC <<'\n';
	       maxAngleBAC <<'\n';
	       minAngleGCV <<'\n';
	       maxAngleGCV <<'\n';
	       minAngleACF <<'\n';
	       maxAngleACF <<'\n';
	       minAngleGCH <<'\n';
	       maxAngleGCH <<'\n';
	       minLegForce <<'\n';
	       maxLegForce <<'\n';
	       displacement <<'\n';
	       resolutionErrors <<'\n';
            }

	 if (page == 1)
	    {
	       // new page required
	       rangeChecks <<'\f';
	       minAngleACB <<'\f';
	       maxAngleACB <<'\f';
	       minAngleBAC <<'\f';
	       maxAngleBAC <<'\f';
	       minAngleGCV <<'\f';
	       maxAngleGCV <<'\f';
	       minAngleACF <<'\f';
	       maxAngleACF <<'\f';
	       minAngleGCH <<'\f';
	       maxAngleGCH <<'\f';
	       minLegForce <<'\f';
	       maxLegForce <<'\f';
	       displacement <<'\f';
	       resolutionErrors <<'\f';

	       page = 0;
	    }
	 else
	    page = 1;
      }
}
