
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#include "Files.H"
#include "Matrix4.H"
#include "HexapodFrame.H"
#include "HexapodBed.H"
#include "HexapodLeg.H"
#include "HexapodTopJoint.H"
#include "HexapodBottomJoint.H"
#include "HexapodPlatform.H"
#include "HexapodMechanism.H"

void 
defineParameters(FrameParameters& frameParameters,
                 BedParameters& bedParameters,
                 MechanismParameters& mechanismParameters);

main()
{
   Matrix4 identity = identity3D();

   FrameParameters frameParameters;
   BedParameters bedParameters;
   MechanismParameters mechanismParameters;
   defineParameters(frameParameters, bedParameters, mechanismParameters);

   HexapodFrame hexapodFrame ("hexapod frame", frameParameters);
   HexapodBed hexapodBed ("hexapod bed", bedParameters);
   HexapodMechanism hexapodMechanism ("hexapod mechanism", mechanismParameters);

   // prefix
   povraySource << "// generated automatically by generatePovraySource\n\n";
   
   // generate frame
   hexapodFrame.emitPovraySource(identity);

   // generate bed
   hexapodBed.emitPovraySource(identity);

   // define platform transformation
   hexapodMechanism.movePlatformTo(Vector3(0.4, 0.4, 0.0),
                                   Vector3(0.0, 0.0, 950));
// hexapodMechanism.movePlatformTo(Vector3(0.0, 0.0, 0.0),
//                                 Vector3(400, 400, 950));
// hexapodMechanism.movePlatformTo(Vector3(0.3, 0.3, 0.0),
//                                 Vector3(-200, -200, 1000));
// hexapodMechanism.movePlatformTo(Vector3(0.0, PI/4, PI/4),
//                                 Vector3(0, 0, 950));
// hexapodMechanism.movePlatformTo(Vector3(PI/4, PI/4, 0),
//                                 Vector3(-600, -600, 1000));

   // generate mechanism
   hexapodMechanism.emitPovraySource(identity);
}
