
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

// simulateCalibration-1.C

// Z measurements on a reference plane at bed level. Readings taken at two
// levels 300mm vertically apart, using an accurate probe extension piece.
// With platform horizontal move C0 probe along line vertically beneath AB0.

#include <std/ctime.h>  // for random number seeding
#include "Files.H"
#include "Matrix4.H"
#include "HexapodFrame.H"
#include "HexapodBed.H"
#include "HexapodLeg.H"
#include "HexapodTopJoint.H"
#include "HexapodBottomJoint.H"
#include "HexapodPlatform.H"
#include "HexapodMechanism.H"

void 
defineParameters(FrameParameters& frameParameters,
                 BedParameters& bedParameters,
                 MechanismParameters& mechanismParameters);

main()
{
   FrameParameters frameParameters;
   BedParameters bedParameters;
   MechanismParameters mechanismParameters;
   defineParameters(frameParameters, bedParameters, mechanismParameters);

   HexapodFrame hexapodFrame ("hexapod frame", frameParameters);
   HexapodBed hexapodBed ("hexapod bed", bedParameters);
   HexapodMechanism hexapodMechanism ("hexapod mechanism", mechanismParameters);

   // seed random number generator, for calibration noise generation
   // this should ensure different random numbers with different program
   // executions, but the effect of increasing the argument to srand should
   // be examined - does an increase of 1 make a large change to the pattern?

   // define max noise, mm
   double maxNoise = 0.0;

   // define the objective function for lp_solve
   constraints << "min: E;\n";

   // correction values for this simulation
   // must be all positive for now - lp_solve
   double values[correctionCount];
   values[0]  = 0.0;  // pointA[0].x  // datum
   values[1]  = 0.0;  // pointA[0].y  // datum
   values[2]  = 3.9;  // pointA[0].z
   values[3]  = 0.0;  // pointA[1].x  // no effect
   values[4]  = 0.0;  // pointA[1].y  // no effect
   values[5]  = 0.0;  // pointA[1].z  // no effect
   values[6]  = 0.0;  // pointA[2].x  // no effect
   values[7]  = 0.0;  // pointA[2].y  // no effect
   values[8]  = 0.0;  // pointA[2].z  // no effect
   values[9]  = 0.0;  // pointB[0].x  // no effect
   values[10] = 4.4;  // pointB[0].y
   values[11] = 2.6;  // pointB[0].z
   values[12] = 0.0;  // pointB[1].x  // no effect
   values[13] = 0.0;  // pointB[1].y  // no effect
   values[14] = 0.0;  // pointB[1].z  // no effect
   values[15] = 0.0;  // pointB[2].x  // no effect
   values[16] = 0.0;  // pointB[2].y  // no effect
   values[17] = 0.0;  // pointB[2].z  // no effect
   values[18] = 2.3;  // lengthA[0]
   values[19] = 0.0;  // lengthA[1]  // no effect
   values[20] = 0.0;  // lengthA[2]  // no effect
   values[21] = 1.5;  // lengthB[0]
   values[22] = 0.0;  // lengthB[1]  // no effect
   values[23] = 0.0;  // lengthB[2]  // no effect
   values[24] = 0.0;  // lengthIJ (C0-C1) // no effect
   values[25] = 0.0;  // lengthJK (C1-C2) // no effect
   values[26] = 0.0;  // lengthKI (C2-C0) // no effect

   // reduce by factor of 10 if required to see effect
   //for (int i = 0; i < correctionCount; i++)
   //   values[i] /= 10;  

   // define correction values
   hexapodMechanism.defineCorrections(values);

   // report correction values
   correction << "\n\n   CALIBRATION SIMULATION CORRECTIONS - MM\n\n";
   hexapodMechanism.reportCorrections();

   int location = 0;
   int axis = VZ;
   for (double z = 800; z < 1200; z += 300)
      for (double y = -600; y <= 600; y += 200)
	 for (double x = 284; x < 285; x++)  // beneath AB0
            {
               hexapodMechanism.movePlatformTo(Vector3(0, 0, 0),
	                                       Vector3(x, y, z));
	       hexapodMechanism.computeCalibrationCoefficients();
       	       hexapodMechanism.generateConstraints(location, axis, maxNoise);
	    }
}
