
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#ifndef HexapodFrameClass
#define HexapodFrameClass

#include <math.h>
#include "Vector3.H"
#include "Primitive.H"
#include "Artifact.H"
#include "HexapodFrameBall.H"
#include "HexapodFrameCone.H"
#include "HexapodFrameTube.H"

struct FrameParameters
{
   double 
      bottomHeight,  // height to bottom square from floor reference plane
      centreHeight,  // height to centre square from floor reference plane
      topHeight,  // height to top square from floor reference plane
      bottomWidth,  // width of bottom square
      centreWidth,  // width of centre square
      topWidth,  // width of top square
      tubeRadius,  // frame tube radius
      sphereRadius;  // frame sphere radius
};

class HexapodFrame: public Artifact
{
   public:
      HexapodFrame() {};
      HexapodFrame
        (char* name, const FrameParameters& parameters);

   private:
      double bottomHeight;
      double centreHeight;
      double topHeight;

      double bottomWidth;
      double centreWidth;
      double topWidth;

      double tubeRadius;
      double sphereRadius;

      double bottomDiagonal;
      Vector3 bottomCorner1;
      Vector3 bottomCorner2;
      Vector3 bottomCorner3;
      Vector3 bottomCorner4;

      Vector3 centreCorner1;
      Vector3 centreCorner2;
      Vector3 centreCorner3;
      Vector3 centreCorner4;

      double topDiagonal;
      Vector3 topCorner1;
      Vector3 topCorner2;
      Vector3 topCorner3;
      Vector3 topCorner4;

      HexapodFrameBall ball;
      HexapodFrameTube 
         tube1,  tube2,  tube3,  tube4,  tube5, 
         tube6,  tube7,  tube8,  tube9,  tube10, 
	 tube11, tube12, tube13, tube14, tube15, 
	 tube16, tube17, tube18, tube19, tube20, 
	 tube21, tube22, tube23, tube24, tube25, 
	 tube26, tube27, tube28;
};

#endif
