
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

// HexapodFrameTube class - standard hexapod frame component
//
// Tube with cone ends - for now the cone is taken as a full cone with the
// apex at the ball centre, with length defined as a constant*tubeRadius in
// the main constructor below.

#include "HexapodFrameTube.H"

HexapodFrameTube::HexapodFrameTube
  (char* name, double radius, Vector3 p1, Vector3 p2) : Artifact(name)
{
   // initialise data member
   tubeRadius = radius;

   // consider cone ends
   const double coneLength = 3*tubeRadius; // say

   double x1, y1, z1, x2, y2, z2;
   x1 = p1[VX]; y1 = p1[VY]; z1 = p1[VZ];
   x2 = p2[VX]; y2 = p2[VY]; z2 = p2[VZ];

   double length;
   length = sqrt((x2 - x1)*(x2 - x1) + 
                 (y2 - y1)*(y2 - y1) + 
		 (z2 - z1)*(z2- z1));

   double xa, ya, za; 
   xa = x1 + (x2 - x1)*coneLength/length;
   ya = y1 + (y2 - y1)*coneLength/length;
   za = z1 + (z2 - z1)*coneLength/length;

   Vector3 pa (xa, ya, za);

   cone1 = Cone(p1, 0, pa, tubeRadius);
   add(&cone1);

   double xb, yb, zb; 
   xb = x2 + (x1 - x2)*coneLength/length;
   yb = y2 + (y1 - y2)*coneLength/length;
   zb = z2 + (z1 - z2)*coneLength/length;

   Vector3 pb (xb, yb, zb);

   cone2 = Cone(pb, tubeRadius, p2, 0);
   add(&cone2);

   cylinder = Cylinder(pa, pb, radius);
   add(&cylinder);

}

void
HexapodFrameTube::operator= 
  (const HexapodFrameTube& that)
{
   // mirror that to this
   memcpy(this, &that, sizeof(*this));

   // fix artifact components
   firstPrimitive = 0;
   add(&cone1);
   add(&cone2);
   add(&cylinder);
}
