
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#ifndef HexapodLegClass
#define HexapodLegClass

#include <math.h>
#include "Primitive.H"
#include "Artifact.H"

struct LegParameters
{
   double 
      screwDiameter,  // ball screw diameter
      screwLength,  // traversable length
      screwTopLength,  // dead length at top
      screwBottomLength,  // dead length at bottom
      nutDiameter,  // ball nut diameter
      nutLength,  // ball nut length
      nutTubeLength,  // nut tube length
      nutTubeOD,  // nut tube outside diameter
      nutTubeID,  // nut tube inside diameter
      nutTubeBottomLength,  // dead length at bottom
      shroudTubeDiameter,
      shroudTubeLength,
      totalBacklash,  // joint bearings + screw/nut
      legLength;  // length between universal joint centres
};

class HexapodLeg: public Artifact
{
   public:
      HexapodLeg() {};
      HexapodLeg
        (char* name, const LegParameters& parameters);
      void operator= 
        (const HexapodLeg& that);
      void setParameters
        (const LegParameters& parameters);
      void setLength
        (double length);
      bool inRange();
      bool tooLong();
      bool tooShort();

   private:
      double 
         screwDiameter,
         screwLength,
         screwTopLength,
         screwBottomLength,
         nutDiameter,
         nutLength,
         nutTubeLength,
         nutTubeOD,
         nutTubeID,
         nutTubeBottomLength,
         shroudTubeDiameter,
         shroudTubeLength,
	 totalBacklash,
         legLength,
	 minLength,
	 maxLength;

      Vector3 
         topEnd,
         bottomEnd;
	     
      Cylinder 
         topLength, 
         screw, 
	 nutTubeBottom, 
	 nutTube;
};

#endif
