
// C++ Vector and Matrix Algebra Routines from Graphics Gems IV
// Author: Jean-Francois DOUE
// Version 3.1 --- October 1993
// Minor modifications by John Storrs

#include <math.h>
#include <iostream.h>
#include <fstream.h>
#include <ctype.h>

#include "Vector6.H"
#include "Matrix6.H"

// Matrix6 Class Member Functions

// CONSTRUCTORS

Matrix6::Matrix6() {}

Matrix6::Matrix6
  (const Vector6& v0, const Vector6& v1, 
   const Vector6& v2, const Vector6& v3,
   const Vector6& v4, const Vector6& v5)
{ v[0] = v0; v[1] = v1; v[2] = v2; v[3] = v3; v[4] = v4; v[5] = v5; }

Matrix6::Matrix6
  (const Matrix6& m)
{ v[0] = m.v[0]; v[1] = m.v[1]; v[2] = m.v[2]; 
  v[3] = m.v[3]; v[4] = m.v[4]; v[5] = m.v[5]; }

Vector6& Matrix6::operator [] ( int i) {
    if (i < 0 || i > 5)
	V_ERROR("Matrix6 [] operator: illegal access; index = " << i << '\n')
    return v[i];
}

// functions

Matrix6 identity6()
{   return Matrix6
      (Vector6(1.0, 0.0, 0.0, 0.0, 0.0, 0.0),
       Vector6(0.0, 1.0, 0.0, 0.0, 0.0, 0.0),
       Vector6(0.0, 0.0, 1.0, 0.0, 0.0, 0.0),
       Vector6(0.0, 0.0, 0.0, 1.0, 0.0, 0.0),
       Vector6(0.0, 0.0, 0.0, 0.0, 1.0, 0.0),
       Vector6(0.0, 0.0, 0.0, 0.0, 0.0, 1.0)); }

// inverse
Matrix6 Matrix6::inverse()  // Gauss-Jordan elimination with partial pivoting
{
    Matrix6 a(*this),  // As a evolves from original mat into identity
	    b(identity6());  // b evolves from identity into inverse(a)
    int i, j, i1;

    // Loop over cols of a from left to right, eliminating above and below diag
    for (j=0; j<6; j++) {   // Find largest pivot in column j among rows j..5
    i1 = j;  // Row with largest pivot candidate
    for (i=j+1; i<6; i++)
	if (fabs(a.v[i].n[j]) > fabs(a.v[i1].n[j]))
	i1 = i;

    // Swap rows i1 and j in a and b to put pivot on diagonal
    swap(a.v[i1], a.v[j]);
    swap(b.v[i1], b.v[j]);

    // Scale row j to have a unit diagonal
    if (a.v[j].n[j]==0.)
	V_ERROR("Matrix6::inverse: singular matrix; can't invert\n");
    b.v[j] /= a.v[j].n[j];
    a.v[j] /= a.v[j].n[j];

    // Eliminate off-diagonal elems in col j of a, doing identical ops to b
    for (i=0; i<6; i++)
	if (i!=j) {
	b.v[i] -= a.v[i].n[j]*b.v[j];
	a.v[i] -= a.v[i].n[j]*a.v[j];
	}
    }
    return b;
}

