
// C++ Vector and Matrix Algebra Routines from Graphics Gems IV
// Author: Jean-Francois DOUE
// Version 3.1 --- October 1993
// Minor modifications by John Storrs

#include <math.h>
#include <iostream.h>
#include <fstream.h>
#include <ctype.h>

#include "Vector6.H"

// Vector6 Class Member Functions			       *

// VECTOR6 ADDED BY JS FOR MATRIX6

// CONSTRUCTORS

Vector6::Vector6() {}

Vector6::Vector6(const double a, const double b, const double c, 
                 const double d, const double e, const double f)
{ n[0] = a; n[1] = b; n[2] = c; n[3] = d; n[4] = e; n[5] = f; }

Vector6::Vector6(const Vector6& v)
{ n[0] = v.n[0]; n[1] = v.n[1]; n[2] = v.n[2]; 
  n[3] = v.n[3]; n[4] = v.n[4]; n[5] = v.n[5]; }

// ASSIGNMENT OPERATORS

Vector6& Vector6::operator = (const Vector6& v)
{ n[0] = v.n[0]; n[1] = v.n[1]; n[2] = v.n[2];
  n[3] = v.n[3]; n[4] = v.n[4]; n[5] = v.n[5];
return *this; }

Vector6& Vector6::operator += ( const Vector6& v )
{ n[0] += v.n[0]; n[1] += v.n[1]; n[2] += v.n[2]; 
  n[3] += v.n[3]; n[4] += v.n[4]; n[5] += v.n[5]; 
return *this; }

Vector6& Vector6::operator -= ( const Vector6& v )
{ n[0] -= v.n[0]; n[1] -= v.n[1]; n[2] -= v.n[2]; 
  n[3] -= v.n[3]; n[4] -= v.n[4]; n[5] -= v.n[5]; 
return *this; }

Vector6& Vector6::operator *= ( const double d )
{ n[0] *= d; n[1] *= d; n[2] *= d; 
  n[3] *= d; n[4] *= d; n[5] *= d; 
return *this; }

Vector6& Vector6::operator /= ( const double d )
{ double d_inv = 1.0/d; 
  n[0] *= d_inv; n[1] *= d_inv; n[2] *= d_inv;
  n[3] *= d_inv; n[4] *= d_inv; n[5] *= d_inv;
  return *this; }

double& Vector6::operator [] ( int i) {
    if (i < 0 || i > 5)
	V_ERROR("Vector6 [] operator: illegal access; index = " << i << '\n')
    return n[i];
}

// FRIENDS
	
Vector6 operator * (const Vector6& a, const double d)
{ return Vector6(d*a.n[0], d*a.n[1], d*a.n[2],
                 d*a.n[3], d*a.n[4], d*a.n[5] ); }

Vector6 operator * (const double d, const Vector6& a)
{ return a*d; }

Vector6 operator / (const Vector6& a, const double d)
{ double d_inv = 1.0/d; 
  return Vector6(a.n[0]*d_inv, a.n[1]*d_inv, a.n[2]*d_inv,
                 a.n[3]*d_inv, a.n[4]*d_inv, a.n[5]*d_inv); }

void swap(Vector6& a, Vector6& b)
{ Vector6 tmp(a); a = b; b = tmp; }

