
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#include "Files.H"
#include "Matrix4.H"
#include "HexapodFrame.H"
#include "HexapodBed.H"
#include "HexapodLeg.H"
#include "HexapodTopJoint.H"
#include "HexapodBottomJoint.H"
#include "HexapodPlatform.H"
#include "HexapodMechanism.H"

void 
defineParameters(FrameParameters& frameParameters,
                 BedParameters& bedParameters,
                 MechanismParameters& mechanismParameters);

main()
{
   FrameParameters frameParameters;
   BedParameters bedParameters;
   MechanismParameters mechanismParameters;
   defineParameters(frameParameters, bedParameters, mechanismParameters);

   HexapodFrame hexapodFrame ("hexapod frame", frameParameters);
   HexapodBed hexapodBed ("hexapod bed", bedParameters);
   HexapodMechanism hexapodMechanism ("hexapod mechanism", mechanismParameters);

   int newPage = 1;   // format control

   // define calibration correction names
   // - copied from HexapodMechanism.C
   char correctionName[correctionCount][charCount];
   correctionName[0]  = "A0X";
   correctionName[1]  = "A0Y";
   correctionName[2]  = "A0Z";
   correctionName[3]  = "A1X";
   correctionName[4]  = "A1Y";
   correctionName[5]  = "A1Z";
   correctionName[6]  = "A2X";
   correctionName[7]  = "A2Y";
   correctionName[8]  = "A2Z";
   correctionName[9]  = "B0X";
   correctionName[10] = "B0Y";
   correctionName[11] = "B0Z";
   correctionName[12] = "B1X";
   correctionName[13] = "B1Y";
   correctionName[14] = "B1Z";
   correctionName[15] = "B2X";
   correctionName[16] = "B2Y";
   correctionName[17] = "B2Z";
   correctionName[18] = "LA0";
   correctionName[19] = "LA1";
   correctionName[20] = "LA2";
   correctionName[21] = "LB0";
   correctionName[22] = "LB1";
   correctionName[23] = "LB2";
   correctionName[24] = "L01";
   correctionName[25] = "L12";
   correctionName[26] = "L20";

   // define calibration measurement location/axis names
   char locationName[locationCount][axisCount][charCount];
   locationName[0][0] = "C0X";
   locationName[0][1] = "C0Y";
   locationName[0][2] = "C0Z";
   locationName[1][0] = "C1X";
   locationName[1][1] = "C1Y";
   locationName[1][2] = "C1Z";
   locationName[2][0] = "C2X";
   locationName[2][1] = "C2Y";
   locationName[2][2] = "C2Z";

   for (int correction = 0; correction < correctionCount; correction++)
      for (int location = 0; location < 3; location++)
         for (int axis = 0; axis < 3; axis++)
	    {
	       if (newPage == 1)  // print title
	          {
                     coefficient << "\n\n      CALIBRATION COEFFICIENTS";
		     coefficient << " FOR A SINGLE CORRECTION - %\n";
		  }
               for (double z = 800; z < 900; z += 300)
                  {
                     coefficient << "\n      Z = " << z;
                     coefficient << "   CORRECTION = ";
                     for (int i = 0; i < charCount - 1; i++)
                        coefficient << correctionName[correction][i];
                     coefficient << "   CALIBRATION = ";
                     for (int i = 0; i < charCount - 1; i++)
                        coefficient << locationName[location][axis][i];
                     coefficient << "\n\n";

                     for (double y = -600; y <= 600; y += 50)
                        {
	                   coefficient << "      ";
                           for (double x = -600; x <= 600; x += 100)
                              {
                                 hexapodMechanism.movePlatformTo
				   (Vector3(0, 0, 0),
	                            Vector3(x, y, z));
			         hexapodMechanism.computeCalibrationCoefficients
				    ();
			         hexapodMechanism.reportCoefficient
			           (correction, location, axis);
	                      }
	                   coefficient <<"\n";
                        }
	             if (newPage == 0)
	                {
	                   newPage = 1;
	                   coefficient <<'\f';
	                }
	             else
	                newPage = 0;
	          }
            }
}
