
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#include "Files.H"
#include "Matrix4.H"
#include "HexapodFrame.H"
#include "HexapodBed.H"
#include "HexapodLeg.H"
#include "HexapodTopJoint.H"
#include "HexapodBottomJoint.H"
#include "HexapodPlatform.H"
#include "HexapodMechanism.H"

void 
defineParameters(FrameParameters& frameParameters,
                 BedParameters& bedParameters,
                 MechanismParameters& mechanismParameters);

void 
printParameters(FrameParameters& frameParameters,
                BedParameters& bedParameters,
                MechanismParameters& mechanismParameters);

main()
{
   FrameParameters frameParameters;
   BedParameters bedParameters;
   MechanismParameters mechanismParameters;
   defineParameters(frameParameters, bedParameters, mechanismParameters);
   printParameters(frameParameters, bedParameters, mechanismParameters);

   HexapodFrame hexapodFrame ("hexapod frame", frameParameters);
   HexapodBed hexapodBed ("hexapod bed", bedParameters);
   HexapodMechanism hexapodMechanism ("hexapod mechanism", mechanismParameters);

   int newPage = 1;   // format control

   // define the z plane spacing for data output
   for (double z = 700; z < 1400; z += 50)
   //for (double z = 800; z < 1200; z += 100)
      {
         if (newPage == 1)  // print title
	    {

         rangeChecks << "\n\n      LEG RANGE CHECK\n";
         rangeChecks << "      L = TOO LONG, S = TOO SHORT\n";
         minAngleACB << "\n\n      MIN ANGLE ACB - DEGREES\n";
         minAngleACB << "      LEG PAIR TRIANGLE BOTTOM\n";
         maxAngleACB << "\n\n      MAX ANGLE ACB - DEGREES\n";
         maxAngleACB << "      LEG PAIR TRIANGLE BOTTOM\n";
         minAngleBAC << "\n\n      MIN ANGLE BAC AND ABC - DEGREES\n";
         minAngleBAC << "      LEG PAIR TRIANGLE TOP\n";
         maxAngleBAC << "\n\n      MAX ANGLE BAC AND ABC - DEGREES\n";
         maxAngleBAC << "      LEG PAIR TRIANGLE TOP\n";
         minAngleGCV << "\n\n      MIN ANGLE GCV - DEGREES\n";
         minAngleGCV << "      LEG PAIR TRIANGLE PLANE TO HORIZONTAL\n";
         maxAngleGCV << "\n\n      MAX ANGLE GCV - DEGREES\n";
         maxAngleGCV << "      LEG PAIR TRIANGLE PLANE TO HORIZONTAL\n";
         minAngleACF << "\n\n      MIN ANGLE ACF AND BCF - DEGREES\n";
         minAngleACF << "      LEG TO BOTTOM JOINT LONG AXIS\n";
         maxAngleACF << "\n\n      MAX ANGLE ACF AND BCF - DEGREES\n";
         maxAngleACF << "      LEG TO BOTTOM JOINT LONG AXIS\n";
         minAngleGCH << "\n\n      MIN ANGLE GCH - DEGREES\n";
         minAngleGCH << "      LEG PAIR TRIANGLE PLANE TO PLATFORM PLANE\n";
         maxAngleGCH << "\n\n      MAX ANGLE GCH - DEGREES\n";
         maxAngleGCH << "      LEG PAIR TRIANGLE PLANE TO PLATFORM PLANE\n";
         minLegForce << "\n\n      MIN ABSOLUTE LEG FORCE";
         minLegForce << " UNDER TEST LOAD - NEWTONS\n";
         maxLegForce << "\n\n      MAX ABSOLUTE LEG FORCE";
         maxLegForce << " UNDER TEST LOAD - NEWTONS\n";
         resolutionErrors << "\n\n      RESOLUTION ERRORS";
         resolutionErrors << " - CEILING(ERROR/RESOLUTION)\n";
         displacement << "\n\n      CUTTER DISPLACEMENT";
         displacement << " UNDER TEST LOAD - MICRONS\n";

	    }

         rangeChecks << "\n      Z = " << z << "\n\n";
         minAngleACB << "\n      Z = " << z << "\n\n";
         maxAngleACB << "\n      Z = " << z << "\n\n";
         minAngleBAC << "\n      Z = " << z << "\n\n";
         maxAngleBAC << "\n      Z = " << z << "\n\n";
         minAngleGCV << "\n      Z = " << z << "\n\n";
         maxAngleGCV << "\n      Z = " << z << "\n\n";
         minAngleACF << "\n      Z = " << z << "\n\n";
         maxAngleACF << "\n      Z = " << z << "\n\n";
         minAngleGCH << "\n      Z = " << z << "\n\n";
         maxAngleGCH << "\n      Z = " << z << "\n\n";
         minLegForce << "\n      Z = " << z << "\n\n";
         maxLegForce << "\n      Z = " << z << "\n\n";
         displacement << "\n      Z = " << z << "\n\n";
         resolutionErrors << "\n      Z = " << z << "\n\n";

         for (double y = -600; y <= 600; y += 50)
            {
	       rangeChecks << "      ";
	       minAngleACB << "      ";
	       maxAngleACB << "      ";
	       minAngleBAC << "      ";
	       maxAngleBAC << "      ";
	       minAngleGCV << "      ";
	       maxAngleGCV << "      ";
	       minAngleACF << "      ";
	       maxAngleACF << "      ";
	       minAngleGCH << "      ";
	       maxAngleGCH << "      ";
	       minLegForce << "      ";
	       maxLegForce << "      ";
	       displacement << "      ";
	       resolutionErrors << "      ";

	       int print = 1;  // control printing
               for (double x = -600; x <= 600; x += 50)
                  {
		   // define the platform orientation
                   hexapodMechanism.movePlatformTo(Vector3(0, 0, 0),
                   //hexapodMechanism.movePlatformTo(Vector3(PI/6, 0, 0),
                   //hexapodMechanism.movePlatformTo(Vector3(0, PI/6, 0),
                   //hexapodMechanism.movePlatformTo(Vector3(PI/9, PI/9, 0),
                   //hexapodMechanism.movePlatformTo(Vector3(PI/6, 0, PI/6),
                   //hexapodMechanism.movePlatformTo(Vector3(PI/6, PI/6, PI/6),
                   //hexapodMechanism.movePlatformTo(Vector3(0, 0, PI/4),
	                                             Vector3(x, y, z));
		     hexapodMechanism.applyCutterForce(Vector3(50, 50, 0),
		                                       Vector3(x, y, z - 150));

                     // print range status every 50mm
	             hexapodMechanism.reportRangeStatus();

                     // print other data every 100mm
		     if (print == 1)
		        {
	                   hexapodMechanism.reportAngles();
	                   hexapodMechanism.reportForces();
	                   hexapodMechanism.reportDisplacement();
	                   hexapodMechanism.reportResolutionError();
			   print = 0;
			}
		     else print = 1;
	          }
              
	       rangeChecks <<'\n';
	       minAngleACB <<'\n';
	       maxAngleACB <<'\n';
	       minAngleBAC <<'\n';
	       maxAngleBAC <<'\n';
	       minAngleGCV <<'\n';
	       maxAngleGCV <<'\n';
	       minAngleACF <<'\n';
	       maxAngleACF <<'\n';
	       minAngleGCH <<'\n';
	       maxAngleGCH <<'\n';
	       minLegForce <<'\n';
	       maxLegForce <<'\n';
	       displacement <<'\n';
	       resolutionErrors <<'\n';
            }

	 if (newPage == 0)
	    {
	       newPage = 1;
	       rangeChecks <<'\f';
	       minAngleACB <<'\f';
	       maxAngleACB <<'\f';
	       minAngleBAC <<'\f';
	       maxAngleBAC <<'\f';
	       minAngleGCV <<'\f';
	       maxAngleGCV <<'\f';
	       minAngleACF <<'\f';
	       maxAngleACF <<'\f';
	       minAngleGCH <<'\f';
	       maxAngleGCH <<'\f';
	       minLegForce <<'\f';
	       maxLegForce <<'\f';
	       displacement <<'\f';
	       resolutionErrors <<'\f';
	    }
	 else
	    newPage = 0;
      }
}
