
// Copyright 1996 John Storrs. All rights reserved. This work may be copied, 
// modified and distributed under the terms of the GNU General Public License.

#include "Files.H"
#include "HexapodFrame.H"
#include "HexapodBed.H"
#include "HexapodLeg.H"
#include "HexapodTopJoint.H"
#include "HexapodBottomJoint.H"
#include "HexapodPlatform.H"
#include "HexapodMechanism.H"

void
printParameters(FrameParameters& frameParameters,
                BedParameters& bedParameters,
                MechanismParameters& mechanismParameters)
{
   parameters << "\n\n      HEXAPOD MACHINE PARAMETERS\n";
   parameters << "\n      FRAME\n";
   parameters << "         bottom height          " 
              << frameParameters.bottomHeight << " mm\n";
   parameters << "         centre height          " 
              << frameParameters.centreHeight << " mm\n";
   parameters << "         top height             " 
              << frameParameters.topHeight << " mm\n";
   parameters << "         bottom width           " 
              << frameParameters.bottomWidth << " mm\n";
   parameters << "         centre width           " 
              << frameParameters.centreWidth << " mm\n";
   parameters << "         top width              " 
              << frameParameters.topWidth << " mm\n";
   parameters << "         tube radius            " 
              << frameParameters.tubeRadius << " mm\n";
   parameters << "         sphere radius          " 
              << frameParameters.sphereRadius << " mm\n";

   parameters << "\n      BED\n";
   parameters << "         width                  " 
              << bedParameters.width << " mm\n";
   parameters << "         height                 " 
              << bedParameters.height << " mm\n";
   parameters << "         thickness              " 
              << bedParameters.thickness << " mm\n";
   parameters << "         support tube radius    " 
              << bedParameters.supportTubeRadius << " mm\n";

   parameters << "\n      MECHANISM\n";
   parameters << "         top circle radius      " 
              << mechanismParameters.topCircleRadius << " mm\n";
   parameters << "         bottom circle radius   " 
              << mechanismParameters.bottomCircleRadius << " mm\n";
   parameters << "         leg pair sector angle  " 
              << mechanismParameters.legPairSectorAngle << " radians\n";
   parameters << "         support height         " 
              << mechanismParameters.supportHeight << " mm\n";

   parameters << "\n      LEGS\n";
   parameters << "         screw diameter         " 
              << mechanismParameters.legParameters.screwDiameter << " mm\n";
   parameters << "         screw length           " 
              <<mechanismParameters.legParameters.screwLength << " mm\n";
   parameters << "         screw top length       " 
              << mechanismParameters.legParameters.screwTopLength << " mm\n";
   parameters << "         screw bottom length    " 
              << mechanismParameters.legParameters.screwBottomLength << " mm\n";
   parameters << "         nut diameter           " 
              << mechanismParameters.legParameters.nutDiameter << " mm\n";
   parameters << "         nut length             " 
              << mechanismParameters.legParameters.nutLength << " mm\n";
   parameters << "         nut tube od            " 
              << mechanismParameters.legParameters.nutTubeOD << " mm\n";
   parameters << "         nut tube id            " 
              << mechanismParameters.legParameters.nutTubeID << " mm\n";
   parameters << "         nut tube bottom length " 
              << mechanismParameters.legParameters.nutTubeBottomLength << " mm\n";
   parameters << "         shroud tube diameter   " 
              << mechanismParameters.legParameters.shroudTubeDiameter << " mm\n";
   parameters << "         shroud tube length     " 
              << mechanismParameters.legParameters.shroudTubeLength << " mm\n";
   parameters << "         total backlash         " 
              << mechanismParameters.legParameters.totalBacklash << " mm\n";
   parameters << "         nut tube length        " 
              << mechanismParameters.legParameters.nutTubeLength << " mm\n";

   parameters << "\n      TOP JOINTS\n";
   parameters << "         ball radius            " 
              << mechanismParameters.topJointParameters.ballRadius << " mm\n";

   parameters << "\n      BOTTOM JOINTS\n";
   parameters << "         ball radius            " 
              << mechanismParameters.bottomJointParameters.ballRadius << " mm\n";

   parameters << "\n      PLATFORM\n";
   parameters << "         radius                 " 
              << mechanismParameters.platformParameters.radius << " mm\n";
   parameters << "         thickness              " 
              << mechanismParameters.platformParameters.thickness << " mm\n";

}
